@@ -17,6 +17,7 @@ const {
   View,
   Animated,
   Platform,
+  UIManager,
   StyleSheet,
   PointPropType,
   ViewPropTypes,
@@ -851,7 +852,7 @@ if (Platform.OS === 'android') {
     nativeOnlyProps
   );
   AndroidHorizontalScrollView = requireNativeComponent(
-    'AndroidHorizontalScrollView',
+    'AndroidHorizontalNestedScrollView',
     (ScrollView: ReactClass<any>),
     nativeOnlyProps
   );
